| /llvm-project-15.0.7/clang/test/SemaCUDA/ |
| H A D | device-var-init.cu | 15 __shared__ int s_v_i = 1; 25 __shared__ T s_t_i = {2}; 36 __shared__ EC s_ec_i(3); 64 __shared__ UC s_uc; 71 __shared__ UD s_ud; 78 __shared__ ECI s_eci; 85 __shared__ NEC s_nec; 92 __shared__ NED s_ned; 99 __shared__ NCV s_ncv; 106 __shared__ VD s_vd; [all …]
|
| H A D | extern-shared.cu | 12 extern __shared__ int x; // expected-error {{__shared__ variable 'x' cannot be 'extern'}} in foo() 13 extern __shared__ int arr[]; // ok in foo() 14 extern __shared__ int arr0[0]; // expected-error {{__shared__ variable 'arr0' cannot be 'extern'}} in foo() 15 extern __shared__ int arr1[1]; // expected-error {{__shared__ variable 'arr1' cannot be 'extern'}} in foo() 16 extern __shared__ int* ptr ; // expected-error {{__shared__ variable 'ptr' cannot be 'extern'}} in foo() 20 extern __shared__ int arr[]; // ok in bar() 21 extern __shared__ int arr0[0]; // expected-error {{__shared__ variable 'arr0' cannot be 'extern'}} in bar() 23 extern __shared__ int* ptr ; // expected-error {{__shared__ variable 'ptr' cannot be 'extern'}} in bar() 27 extern __shared__ int global_arr[]; // ok 35 extern __shared__ int global_arr[]; // rdc-warning {{has internal linkage but is not defined}} [all …]
|
| H A D | bad-attributes.cu | 20 __shared__ int d1; 21 __shared__ void d2(); // expected-warning {{attribute only applies to variables}} 30 __device__ __shared__ int z3; 39 __constant__ __shared__ int z8; // expected-error {{attributes are not compatible}} 42 __shared__ __device__ int z9; 43 __shared__ __constant__ int z10; // expected-error {{attributes are not compatible}} 45 __constant__ __shared__ int z10a; // expected-error {{attributes are not compatible}} 68 …__shared__ int s; // expected-error {{__shared__ local variables not allowed in __host__ functions… in host_fn()
|
| H A D | union-init.cu | 39 __shared__ B b; in foo() 40 __shared__ C c; in foo() 42 __shared__ D d; in foo()
|
| H A D | qualifiers.cu | 24 __shared__ int __thread shared_tls_var; // expected-error {{thread-local storage is not supported f… 31 __shared__ int __thread shared_tls_var;
|
| H A D | managed-var.cu | 28 __managed__ __shared__ int m5; 32 __shared__ __managed__ int m5a;
|
| H A D | attr-declspec.cu | 27 __declspec(__shared__) float *g_shared;
|
| H A D | constexpr-var.cu | 89 __shared__ int b;
|
| H A D | const-var.cu | 88 __shared__ int b;
|
| H A D | device-use-host-var.cu | 38 __shared__ int global_shared_var;
|
| /llvm-project-15.0.7/clang/test/CodeGenCUDA/ |
| H A D | device-var-init.cu | 25 __shared__ int s_v; 50 __shared__ T s_t; 68 __shared__ EC s_ec; 79 __shared__ ED s_ed; 89 __shared__ ECD s_ecd; 100 __shared__ ETC s_etc; 118 __shared__ T_B_T s_t_b_t; 129 __shared__ T_F_T s_t_f_t; 140 __shared__ T_FA_T s_t_fa_t; 152 __shared__ EC_I_EC s_ec_i_ec; [all …]
|
| H A D | address-spaces.cu | 16 __shared__ int k; 40 __shared__ int lk; in foo() 46 __shared__ MyStruct a; in func0() 59 __shared__ float a; in func1() 66 __shared__ float a[256]; in func2() 74 __shared__ float a; in func3() 82 __shared__ float a; in func4() 89 __shared__ float b;
|
| H A D | debug-info-address-class.cu | 10 __device__ __shared__ int FileVar1; 21 __shared__ int FuncVar0; in kernel1()
|
| H A D | builtins-amdgcn.cu | 53 __shared__ float shared; in test_ds_fmax() 70 __shared__ float shared; in test_ds_fadd()
|
| H A D | filter-decl.cu | 22 __shared__ char shareddata[256];
|
| H A D | device-stub.cu | 82 __shared__ int shared_var;
|
| /llvm-project-15.0.7/clang/test/CodeGenHIP/ |
| H A D | hipspv-addr-spaces.cpp | 5 #define __shared__ __attribute__((shared)) macro 17 __shared__ int s;
|
| /llvm-project-15.0.7/clang/test/CodeGenCUDA/Inputs/ |
| H A D | cuda.h | 10 #define __shared__ __attribute__((shared)) macro 20 #define __shared__ macro
|
| /llvm-project-15.0.7/clang/test/CodeGen/ |
| H A D | builtins-nvptx-ptx50.cu | 10 #define __shared__ __attribute__((shared)) macro
|
| H A D | builtins-nvptx.c | 28 #define __shared__ __attribute__((shared)) macro 205 __shared__ int si; 207 __shared__ long sl; 209 __shared__ long long sll;
|
| H A D | builtins-nvptx-ptx60.cu | 18 #define __shared__ __attribute__((shared)) macro
|
| /llvm-project-15.0.7/clang/test/PCH/Inputs/ |
| H A D | cuda.h | 9 #define __shared__ __attribute__((shared)) macro
|
| /llvm-project-15.0.7/clang/test/SemaCUDA/Inputs/ |
| H A D | cuda.h | 12 #define __shared__ __attribute__((shared)) macro
|
| /llvm-project-15.0.7/clang/lib/Headers/ |
| H A D | __clang_hip_runtime_wrapper.h | 24 #define __shared__ __attribute__((shared)) macro
|
| /llvm-project-15.0.7/clang/test/AST/Inputs/ |
| H A D | cuda.h | 12 #define __shared__ __attribute__((shared)) macro
|